/**
*
* Name		gvatrect -- Change attributes on a rectangle
*			    via BIOS or directly
*
* Synopsis	num_writ = gvatrect(u_row,u_col,l_row,l_col,fore,back);
*
*		int  num_writ	Number of character cells actually changed
*		int  u_row	Top row to write (0 = top of screen)
*		int  u_col	Leftmost column to write (0 = left edge)
*		int  l_row	Bottom row to write
*		int  l_col	Rightmost column to write
*		int  fore,back	Foreground and background attributes
*
* Description	This function fills a rectangular area on the current
*		display page with a given attribute without affecting
*		the characters already displayed there.  The cursor is
*		not moved.
*
*		The upper left corner of the region is (u_row,u_col),
*		where (0,0) represents the upper left corner of the
*		entire screen.	The lower right corner of the region is
*		(l_row,l_col), where (24,79) is the lower right corner
*		of an 80-by-25 screen.
*
*		The returned value reports the number of "character
*		cells" written, where "character cells" means the number
*		of physical spaces on the screen.
*
*		This function is available in two versions.  These call
*		SCATRECT (which uses BIOS only) or VIATRECT (direct to
*		video memory) depending on the value of the symbol
*		GV_OPTION.  These versions are therefore subject to
*		differing limitations.
*
* Returns	num_writ	Number of character cells changed
*
* Version	3.0  (C)Copyright Blaise Computing Inc. 1986
*
**/

#include <bgenvid.h>

int gvatrect(u_row,u_col,l_row,l_col,fore,back)
int u_row,u_col,l_row,l_col;
int fore,back;
{
#if (GV_OPTION) == (GV_BIOS)

    return scatrect(u_row,u_col,l_row,l_col,fore,back);

#else

    return viatrect(u_row,u_col,l_row,l_col,fore,back);

#endif
}
