/**
*
* Name		gvhoriz -- Horizontally scroll columns of text on the
*			   current display page via BIOS or directly.
*
* Synopsis	scrolled = gvhoriz(num_cols,attrib,
*					u_row,u_col,l_row,l_col,dir);
*
*		int scrolled	  Number of columns actually scrolled.
*		int num_cols	  Number of columns to scroll.	A value
*				  of 0 specifies that all columns
*				  within the region should be scrolled
*				  (thus clearing the region).
*		int attrib	  If the screen is in text mode, this
*				  is the attribute to be used on the
*				  vacant columns.  It has the background
*				  attribute in the high order four bits
*				  of the low order byte, and the
*				  foreground in the low order nybble.
*				  If the screen is in graphics mode, this
*				  is the color to use for the scrolled text.
*		int u_row,u_col   Upper left corner of region.
*		int l_row,l_col   Lower right corner of region.
*		int dir 	  Scrolling direction (SCR_LEFT or
*				  SCR_RIGHT).
*
* Description	This function moves columns of characters within a
*		defined rectangular region to the left or right.  The
*		vacant columns are filled with blanks and a specified
*		attribute.
*
*		This function is available in two versions.  These call
*		SCHORIZ (which uses BIOS only) or VIHORIZ (direct to
*		video memory) depending on the value of the symbol
*		GV_OPTION.  These versions are therefore subject to
*		differing limitations.
*
* Returns	scrolled	  Number of columns actually scrolled.
*
* Version	3.0  (C)Copyright Blaise Computing Inc. 1986
*
**/

#include <bgenvid.h>

int gvhoriz(num_cols,attrib,u_row,u_col,l_row,l_col,dir)
int num_cols,attrib,u_row,u_col,l_row,l_col,dir;
{
#if (GV_OPTION) == (GV_BIOS)

    return schoriz(num_cols,attrib,u_row,u_col,l_row,l_col,dir);

#else

    return vihoriz(num_cols,attrib,u_row,u_col,l_row,l_col,dir);

#endif
}
