/**
*
* Name		gvscroll -- Vertically scroll lines of text on the current
*			    display page directly or via the BIOS.
*
* Synopsis	iret = gvscroll(num_lines,attrib,u_row,u_col,l_row,l_col,
*			  dir);
*
*		int iret	  Number of lines actually scrolled.
*		int num_lines	  Number of lines to scroll.  A value of 0
*				  specifies that all lines within the
*				  region should be scrolled (thus clearing
*				  the region)
*		int attrib	  If the screen is in text mode, this
*				  is the attribute to be used on the
*				  vacant lines.  It has the background
*				  attribute in the high order four bits
*				  of the low order byte, and the
*				  foreground in the low order nybble.
*				  If the screen is in graphics mode and
*				  the current page is not active, this
*				  is the color to use for the scrolled text.
*				  If the screen is in graphics mode and
*				  the current page is active, this is
*				  ignored.
*		int u_row,u_col   Upper left corner of region.
*		int l_row,l_col   Lower right corner of region.
*		int dir 	  Scrolling direction (SCR_UP or SCR_DOWN).
*
* Description	This function moves lines of characters (with their
*		attributes) up or down within a defined rectangular
*		region.  The vacant lines are filled with blanks and a
*		specified attribute.
*
*		This function is available in two versions.  These call
*		SCPSCROL (which uses BIOS only) or VISCROLL (direct to
*		video memory) depending on the value of the symbol
*		GV_OPTION.  These versions are therefore subject to
*		differing limitations.
*
* Returns	iret		  Number of lines actually scrolled.
*
* Version	3.0  (C)Copyright Blaise Computing Inc. 1986
*
**/

#include <bgenvid.h>

int gvscroll(num_lines,attrib,u_row,u_col,l_row,l_col,dir)
int num_lines,attrib,u_row,u_col,l_row,l_col,dir;
{
#if (GV_OPTION) == (GV_BIOS)

    return scpscrol(num_lines,attrib,u_row,u_col,l_row,l_col,dir);

#else

    return viscroll(num_lines,attrib,u_row,u_col,l_row,l_col,dir);

#endif
}
