/**
*
* Name		gvwrrect -- Write rectangular region directly to
*			    the current display page
*
* Synopsis	num_writ = gvwrrect(u_row,u_col,l_row,l_col,
*				    buffer,fore,back,option);
*
*		int  num_writ	Number of spaces actually written
*		int  u_row	Top row to write (0 = top of screen)
*		int  u_col	Leftmost column to write (0 = left edge)
*		int  l_row	Bottom row to write
*		int  l_col	Rightmost column to write
*		char *buffer	Space containing the data to write
*		int  fore	If CHARS_ONLY is specified, a value
*				between 0 and 15 specifies a new
*				foreground attribute.
*				If fore is -1, see the documentation
*				for the underlying function (SCWRRECT or
*				VIWRRECT).
*		int  back	If CHARS_ONLY is specified, a value
*				between 0 and 15 specifies a new
*				background attribute.
*				If back is -1, see the documentation
*				for the underlying function (SCWRRECT or
*				VIWRRECT).
*		int  option	One bit in the option value tells VIWRRECT
*				how the buffer is constructed.	The two
*				possible values for this bit are:
*
*		      Value	    Meaning
*		      -----------   ------------------------------------
*		      CHARS_ONLY    Buffer contains characters only.
*				    The values of fore and back are used
*				    as attributes, unless they are both -1,
*				    in which case the existing screen
*				    attributes are left unchanged.
*		      CHAR_ATTR     Buffer contains (char,attr) pairs.
*				    The values of fore and back are ignored.
*
* Description	This function fills a rectangular region on the current
*		display page with characters from a buffer with or
*		without their corresponding video attributes.  The data
*		is written row by row.	The cursor is not moved.
*
*		The upper left corner of the region is (u_row,u_col),
*		where (0,0) represents the upper left corner of the
*		entire screen.	The lower right corner of the region is
*		(l_row,l_col), where (24,79) is the lower right corner
*		of an 80-by-25 screen.
*
*		Be aware that this function does NOT recognize NULs
*		('\0') or any other special characters.
*
*		This function is available in two versions.  These call
*		SCWRRECT (which uses BIOS only) or VIWRRECT (direct to
*		video memory) depending on the value of the symbol
*		GV_OPTION.  These versions are therefore subject to
*		differing limitations.
*
* Returns	num_writ	Number of spaces written
*
* Version	3.0  (C)Copyright Blaise Computing Inc. 1986
*
**/

#include <bgenvid.h>

int gvwrrect(u_row,u_col,l_row,l_col,buffer,fore,back,option)
int  u_row,u_col,l_row,l_col;
char *buffer;
int  fore,back,option;
{
#if (GV_OPTION) == (GV_BIOS)

    return scwrrect(u_row,u_col,l_row,l_col,buffer,fore,back,option);

#else

    return viwrrect(u_row,u_col,l_row,l_col,buffer,fore,back,option);

#endif
}
