/**
*
* Name		isretvec -- Return interrupt vector
*		(Formerly called PCRETVEC.)
*
* Synopsis	ercode = isretvec(intype,pvector);
*
*		int ercode	  Error code:  0 if okay,
*				  1 if intype is out of 0-255 range.
*		int intype	  Interrupt type number
*		ADS *pvector	  Interrupt vector
*
* Description	This function returns the interrupt vector associated
*		with the specified interrupt type.  The CS:IP vector is
*		returned in the segment:offset components of *pvector.
*
*		Use ISSETVEC to set an interrupt vector.
*
* Returns	ercode		  If intype is not in the range 0 to 255
*				  1 is returned; otherwise 0.
*		pvector 	  Interrupt vector (CS:IP address of
*				  of interrupt handling routine).
*
* Version	3.0  (C)Copyright Blaise Computing Inc.  1983, 1984, 1986
*
**/

#include <bisr.h>

int isretvec(intype,pvector)
int intype;
ADS *pvector;
{
    DOSREG dos_reg;

    if (utrange(intype,0,255))
       return(1);
    dos_reg.ax = utbyword(0x35,intype);
    dos(&dos_reg);
    pvector->s = dos_reg.es;
    pvector->r = dos_reg.bx;

    return(0);
}
