/**
*
* Name		sccursor -- Set the cursor size for the active page.
*
* Synopsis	scur = sccursor(off,high,low);
*
*		int scur	  Value of "off" parameter
*		int off 	  Cursor off indicator (0 = on)
*		int high	  The cursor upper scan line
*		int low 	  The cursor lower scan line
*
* Description	This function sets and records the size of the cursor
*		for the active (displayed) page.  The cursor size is
*		determined by the upper and lower scan lines, whose
*		values can be between 0 and 13 for the Monochrome
*		Adapter, and 0 and 7 for the Color/Graphics Adapter.  If
*		off is nonzero, the cursor is turned off (no display);
*		otherwise it is on.
*
*		Use SCPGCUR to set the cursor size and on/off state for
*		the current display page regardless of whether it is
*		active (displayed).  Use SCCURST to return the size and
*		on/off state of the current page's cursor.
*
* Returns	scur		  Value of "off" parameter (0 = on)
*
* Version	3.0  (C)Copyright Blaise Computing Inc. 1983, 1984, 1986
*
**/

#include <bscreen.h>

int sccursor(off,high,low)
int off;
int high;
int low;
{
    int mode,columns,act_page,old_page;

    old_page = b_curpage;	      /* Save current page number.    */
    scmode(&mode,&columns,&act_page); /* Get active page.	      */
    scpage(act_page);		      /* Designate active page as     */
				      /* current.		      */

    scpgcur(off,high,low,CUR_ADJUST); /* Set cursor for current page  */
				      /* (which now coincides with    */
				      /* active page).		      */

    scpage(old_page);		      /* Restore previous current page*/

    return(off);
}
